/****************************************************************************\
*                                                                            *
*  FGIW2.C                                                                   *
*                                                                            *
*  This example shows how to play a flic file from an FGI library, using     *
*  either fgi_showflic() or the low-level fgi_flicxxx() routines.            *
*                                                                            *
\****************************************************************************/

#include <fgwin.h>
#include <fgiwin.h>

long WINAPI _export WindowProc(HWND,UINT,UINT,LONG);

int PASCAL WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance,
                    LPSTR lpszCmdParam, int nCmdShow)
{
   static char szAppName[] = "FGIW2";
   HWND        window;
   MSG         msg;
   WNDCLASS    wndclass;

   if (!hPrevInstance)
   {
      wndclass.style         = CS_HREDRAW | CS_VREDRAW | CS_OWNDC;
      wndclass.lpfnWndProc   = WindowProc;
      wndclass.cbClsExtra    = 0;
      wndclass.cbWndExtra    = 0;
      wndclass.hInstance     = hInstance;
      wndclass.hIcon         = LoadIcon(NULL,IDI_APPLICATION);
      wndclass.hCursor       = LoadCursor(NULL,IDC_ARROW);
      wndclass.hbrBackground = NULL;
      wndclass.lpszMenuName  = NULL;
      wndclass.lpszClassName = szAppName;
      RegisterClass (&wndclass);
   }

   window = CreateWindow(
      szAppName,             // window class name
      "Example FGIW2",       // window caption
      WS_OVERLAPPEDWINDOW,   // window style
      CW_USEDEFAULT,         // initial x position
      CW_USEDEFAULT,         // initial y position
      CW_USEDEFAULT,         // initial x size
      CW_USEDEFAULT,         // initial y size
      NULL,                  // parent window handle
      NULL,                  // window menu handle
      hInstance,             // program instance handle
      NULL);                 // creation parameters

   ShowWindow(window,nCmdShow);
   UpdateWindow(window);

   while (GetMessage(&msg,NULL,0,0))
   {
      TranslateMessage(&msg);
      DispatchMessage(&msg);
   }
   return msg.wParam;
}

/****************************************************************************\
*                                                                            *
*  WindowProc                                                                *
*                                                                            *
*  Window procedure to handle messages sent to the window.                   *
*                                                                            *
\****************************************************************************/

HDC      hdc;
HPALETTE hpal;
UINT     cxClient, cyClient;
int      hvb, hfgi;
char     context[20];

long WINAPI _export WindowProc(HWND window, UINT message,
                               UINT wParam, LONG lParam)
{
   PAINTSTRUCT ps;

   switch (message)
   {
      case WM_CREATE:
         hdc = GetDC(window);
         fg_setdc(hdc);
         hpal = fg_defpal();
         fg_realize(hpal);

         fg_vbinit();
         hvb = fg_vballoc(320,200);
         fg_vbopen(hvb);
         fg_vbcolors();

         hfgi = fgi_open("EXAMPLE.FGI");
         if (hfgi == 0)
         {
            MessageBox(window,"Unable to open FGI file.","Error",MB_ICONSTOP|MB_OK);
            DestroyWindow(window);
            return 0;
         }
         fgi_flicopen("GLASS.FLI",context,hfgi);
         fg_flicplay(context,1,0);
         return 0;

      case WM_KEYDOWN:
         switch (wParam)
         {
            case VK_F1:
               fgi_showflic("GLASS.FLI",2,0,hfgi);
               break;
            case VK_F2:
               fgi_flicskip(context,-1);
               while (fg_flicplay(context,1,0) > 0)
                  fg_vbscale(0,fg_getmaxx(),0,fg_getmaxy(),0,cxClient-1,0,cyClient-1);
               fgi_flicskip(context,-1);
               while (fg_flicplay(context,1,0) > 0)
                  fg_vbscale(0,fg_getmaxx(),0,fg_getmaxy(),0,cxClient-1,0,cyClient-1);
               break;
         }
         return 0;

      case WM_PAINT:
         BeginPaint(window,&ps);
         fg_vbscale(0,fg_getmaxx(),0,fg_getmaxy(),0,cxClient-1,0,cyClient-1);
         EndPaint(window,&ps);
         return 0;

      case WM_SETFOCUS:
         fg_realize(hpal);
         InvalidateRect(window,NULL,TRUE);
         return 0;

      case WM_SIZE:
         cxClient = LOWORD(lParam);
         cyClient = HIWORD(lParam);
         return 0;

      case WM_DESTROY:
         fgi_close(hfgi);
         fg_vbclose();
         fg_vbfree(hvb);
         fg_vbfin();
         DeleteObject(hpal);
         ReleaseDC(window,hdc);
         PostQuitMessage(0);
         return 0;
   }
   return DefWindowProc(window,message,wParam,lParam);
}
